Installation
============

Install from PyPI
-----------------

.. code-block:: bash

    pip install moose-fs

Install from Source
-------------------

.. code-block:: bash

    git clone https://github.com/CI4CB-lab/moosefs.git
    cd moosefs
    pip install .

Editable/development installs:

.. code-block:: bash

    pip install -e .
    # optional extras
    pip install -e .[dev]

